@@ -6,7 +6,7 @@
 #' \code{plot_mcc} constructs a control chart for the marginal distribution
 #' of a categorical series
 #'
-#' @param series An object of type \code{tsibble} (see R package \code{tsibble}), whose column named Values
+#' @param series An object of type \code{tsibble} (see R package \code{tsibble}), whose column named Value
 #' contains the values of the corresponding CTS. This column must be of class \code{factor} and its levels
 #' must be determined by the range of the CTS.
 #' @param c The hypothetical marginal distribution.
@@ -60,7 +60,7 @@ plot_mcc <- function(series, c, sigma, lambda = 0.99, k = 3.3, min_max = FALSE,
                                    plot = TRUE, title = 'Control chart (marginal)',...) {
 
   x1 <- y1 <- x2 <- y2 <- NULL
-  check_cts(series$Value)
+  check_cts(series)
   series_length <- length(series$Value) # Series length
   categories <- levels(series$Value)
   n_cat <- length(categories) # Number of categories in the dataset
