@@ -6,7 +6,7 @@
 #' \code{plot_ph} constructs the pattern histogram associated with a given category of a
 #' categorical time series.
 #'
-#' @param series An object of type \code{tsibble} (see R package \code{tsibble}), whose column named Values
+#' @param series An object of type \code{tsibble} (see R package \code{tsibble}), whose column named Value
 #' contains the values of the corresponding CTS. This column must be of class \code{factor} and its levels
 #' must be determined by the range of the CTS.
 #' @param category The selected category.
@@ -41,7 +41,7 @@ plot_ph <- function(series, category,
                               plot = TRUE,
                               title = paste0('Pattern histogram (', category, ')'), ...) {
   x <- NULL
-  check_cts(series$Value)
+  check_cts(series)
   series_length <- length(series$Value) # Series length
   categories <- levels(series$Value)
   n_cat <- length(categories) # Number of categories in the dataset
